==> igniteui-react-core-16.16.1.tgz: package/esm5/lib/BarFragmentDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { ColumnFragmentDescriptionMetadata } from "./ColumnFragmentDescriptionMetadata";
import { BarFragmentDescription } from "./BarFragmentDescription";
/**
 * @hidden
 */
var BarFragmentDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(BarFragmentDescriptionMetadata, _super);
    function BarFragmentDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    BarFragmentDescriptionMetadata.b = function (a) {
        if (BarFragmentDescriptionMetadata.a == null) {
            BarFragmentDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            BarFragmentDescriptionMetadata.c(BarFragmentDescriptionMetadata.a);
        }
        if (a.g(BarFragmentDescriptionMetadata.a)) {
            return;
        }
        a.s(BarFragmentDescriptionMetadata.a);
    };
    BarFragmentDescriptionMetadata.c = function (a) {
        ColumnFragmentDescriptionMetadata.c(a);
    };
    BarFragmentDescriptionMetadata.d = function (a) {
        BarFragmentDescriptionMetadata.b(a);
        a.u("BarFragment", function () { return new BarFragmentDescription(); });
        a.t("BarFragment", BarFragmentDescriptionMetadata.a);
    };
    BarFragmentDescriptionMetadata.$t = markType(BarFragmentDescriptionMetadata, 'BarFragmentDescriptionMetadata');
    BarFragmentDescriptionMetadata.a = null;
    return BarFragmentDescriptionMetadata;
}(Base));
export { BarFragmentDescriptionMetadata };

==> igniteui-react-core-18.1.2.tgz: package/esm5/lib/BarFragmentDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { ColumnFragmentDescriptionMetadata } from "./ColumnFragmentDescriptionMetadata";
import { BarFragmentDescription } from "./BarFragmentDescription";
/**
 * @hidden
 */
var BarFragmentDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(BarFragmentDescriptionMetadata, _super);
    function BarFragmentDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    BarFragmentDescriptionMetadata.b = function (a) {
        if (BarFragmentDescriptionMetadata.a == null) {
            BarFragmentDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            BarFragmentDescriptionMetadata.c(BarFragmentDescriptionMetadata.a);
        }
        if (a.j(BarFragmentDescriptionMetadata.a)) {
            return;
        }
        a.y(BarFragmentDescriptionMetadata.a);
    };
    BarFragmentDescriptionMetadata.c = function (a) {
        ColumnFragmentDescriptionMetadata.c(a);
    };
    BarFragmentDescriptionMetadata.d = function (a) {
        BarFragmentDescriptionMetadata.b(a);
        a.aa("BarFragment", function () { return new BarFragmentDescription(); });
        a.z("BarFragment", BarFragmentDescriptionMetadata.a);
    };
    BarFragmentDescriptionMetadata.$t = markType(BarFragmentDescriptionMetadata, 'BarFragmentDescriptionMetadata');
    BarFragmentDescriptionMetadata.a = null;
    return BarFragmentDescriptionMetadata;
}(Base));
export { BarFragmentDescriptionMetadata };
